import 'package:flutter/material.dart';
import 'package:vdocipher_flutter/src/views/playback_event.dart';
import 'package:vdocipher_flutter/src/web/vdo_web_player_controller.dart';

import '../../vdocipher_flutter.dart';

class VdoWebPlayer extends StatefulWidget {
  final EmbedInfo embedInfo;
  final double aspectRatio;
  final Function(VdoError vdoError)? onError;
  final PlaybackEventListener? playbackEventListener;
  final Function(bool isFullscreen)? onFullscreenChange;
  final Function(bool isInPictureInPictureMode)? onPictureInPictureModeChanged;
  final Function(VdoPlayerController vdoPlayerController) onPlayerCreated;
  final bool controls;
  final WebPlayerController controller;

  const VdoWebPlayer(
      {Key? key,
      required this.embedInfo,
      required this.onPlayerCreated,
      this.aspectRatio = 16 / 9,
      this.controls = true,
      this.playbackEventListener,
      required this.onFullscreenChange,
      this.onPictureInPictureModeChanged,
      this.onError,
      required this.controller})
      : super(key: key);

  @override
  State<VdoWebPlayer> createState() => _VideoPlayerState();
}

class _VideoPlayerState extends State<VdoWebPlayer> {
  _VideoPlayerState() {
    _listener = (textureId) {
      final int newTextureId = textureId;
      if (newTextureId != _textureId) {
        setState(() {
          _textureId = newTextureId;
        });
      }
      widget.onPlayerCreated(widget.controller);
    };
  }

  bool _hasError = false;

  late Function(int textureId) _listener;

  late int _textureId;

  @override
  void initState() {
    super.initState();
    widget.controller.initialize(widget.embedInfo, widget.controls);
    _textureId = widget.controller.textureId;
    widget.controller.addPlatformViewCreatedCallback(_listener);
  }

  @override
  void didUpdateWidget(VdoWebPlayer oldWidget) {
    super.didUpdateWidget(oldWidget);
    oldWidget.controller.removeOnPlatformViewCreatedListener(_listener);
    widget.controller.addPlatformViewCreatedCallback(_listener);
  }

  @override
  void deactivate() {
    super.deactivate();
  }

  @override
  Widget build(BuildContext context) {
    widget.controller.addListener(() {
      if (widget.controller.value.vdoError != null) {
        if (!_hasError) widget.onError?.call(widget.controller.value.vdoError!);
        _hasError = true;
      } else {
        _hasError = false;
      }
    });
    if (_textureId == WebPlayerController.kUninitializedTextureId) {
      return Container();
    } else {
      return videoPlayerPlatform.buildView(_textureId);
    }
  }
}
